@@ -3,10 +3,10 @@
    provide dicts that map from attribute names to attribute values.
 """
 
-# Copyright (c) 2009-2014, Aalborg University (chr@cs.aau.dk)
+# Copyright (c) 2009-2016, Aalborg University (pygrametl@cs.aau.dk)
 # All rights reserved.
 
-# Redistribution and use in source anqd binary forms, with or without
+# Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
 
 # - Redistributions of source code must retain the above copyright notice, this
@@ -28,8 +28,9 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 from csv import DictReader
-
 import sys
+
+
 if sys.platform.startswith('java'):
     # Jython specific code
     from pygrametl.jythonmultiprocessing import Queue, Process
@@ -37,9 +38,9 @@ else:
     from multiprocessing import Queue, Process
 
 try:
-    from Queue import Empty # Python 2
+    from Queue import Empty  # Python 2
 except ImportError:
-    from queue import Empty # Python 3
+    from queue import Empty  # Python 3
 
 # Jython 2.5.X specific code
 try:
@@ -49,23 +50,67 @@ except NameError:
 
 __author__ = "Christian Thomsen"
 __maintainer__ = "Christian Thomsen"
-__version__ = '2.3'
-__all__ = ['CSVSource', 'SQLSource', 'JoiningSource', 'HashJoiningSource', 
-           'MergeJoiningSource', 'BackgroundSource', 'ProcessSource', 
-           'TransformingSource', 'UnionSource', 'CrossTabbingSource', 
-           'FilteringSource', 'DynamicForEachSource', 'RoundRobinSource']
+__version__ = '2.5.0'
+__all__ = ['CSVSource', 'TypedCSVSource', 'SQLSource', 'JoiningSource',
+           'HashJoiningSource', 'MergeJoiningSource', 'BackgroundSource',
+           'ProcessSource', 'TransformingSource', 'UnionSource',
+           'CrossTabbingSource', 'FilteringSource', 'DynamicForEachSource',
+           'RoundRobinSource']
 
 
 CSVSource = DictReader
 
 
+class TypedCSVSource(DictReader):
+    """A class for iterating a CSV file and type cast the values."""
+
+    def __init__(self, csvfile, casts, fieldnames=None, restkey=None,
+                 restval=None, dialect='excel', *args, **kwds):
+        """Arguments:
+           - f: An iterable object such as as file. Passed on to
+             csv.DictReader
+           - casts: A dict mapping from attribute names to functions to apply
+             to these names, e.g., {'id':int, 'salary':float}
+           - fieldnames: Passed on to csv.DictReader
+           - restkey: Passed on to csv.DictReader
+           - restval: Passed on to csv.DictReader
+           - dialect: Passed on to csv.DictReader
+           - *args: Passed on to csv.DictReader
+           - **kwds: Passed on to csv.DictReader
+        """
+        DictReader.__init__(self, csvfile, fieldnames=fieldnames,
+                            restkey=restkey, restval=restval, dialect=dialect,
+                            *args, **kwds)
+
+        if not type(casts) == dict:
+            raise TypeError("The casts argument must be a dict")
+        for v in casts.values():
+            if not callable(v):
+                raise TypeError("The values in casts must be callable")
+        self._casts = casts
+
+    def __next__(self):  # For Python 3
+        row = DictReader.__next__(self)
+        for (att, func) in self._casts.items():
+            row[att] = func(row[att])
+        return row
+
+    def next(self):  # For Python 2
+        row = DictReader.next(self)
+        for (att, func) in self._casts.items():
+            row[att] = func(row[att])
+        return row
+
+
 class SQLSource(object):
+
     """A class for iterating the result set of a single SQL query."""
 
-    def __init__(self, connection, query, names=(), initsql=None, \
-                     cursorarg=None, parameters=None):
+    def __init__(self, connection, query, names=(), initsql=None,
+                 cursorarg=None, parameters=None):
         """Arguments:
-           - connection: the PEP 249 connection to use. NOT a ConnectionWrapper!
+           - connection: the PEP 249 connection to use. NOT a
+             ConnectionWrapper!
            - query: the query that generates the result
            - names: names of attributes in the result. If not set,
              the names from the database are used. Default: ()
@@ -110,8 +155,8 @@ class SQLSource(object):
                     # psycopg2 cursor.
                     names = [t[0] for t in self.cursor.description]
                 if len(names) != len(data[0]):
-                    raise ValueError(\
-                        "Incorrect number of names provided. " + \
+                    raise ValueError(
+                        "Incorrect number of names provided. " +
                         "%d given, %d needed." % (len(names), len(data[0])))
                 for row in data:
                     yield dict(zip(names, row))
@@ -123,6 +168,7 @@ class SQLSource(object):
 
 
 class ProcessSource(object):
+
     """A class for iterating another source in a separate process"""
 
     def __init__(self, source, batchsize=500, queuesize=20):
@@ -133,7 +179,7 @@ class ProcessSource(object):
            - queuesize: the maximum number of batches that can wait in a queue
              between the processes. 0 means unlimited. Default: 20
         """
-        if type(batchsize) != int or batchsize < 1:
+        if not isinstance(batchsize, int) or batchsize < 1:
             raise ValueError('batchsize must be a positive integer')
         self.__source = source
         self.__batchsize = batchsize
@@ -143,7 +189,7 @@ class ProcessSource(object):
         p.start()
 
     def __worker(self):
-        batch = []    
+        batch = []
         try:
             for row in self.__source:
                 batch.append(row)
@@ -175,12 +221,13 @@ class ProcessSource(object):
             for row in data:
                 yield row
 
-BackgroundSource = ProcessSource # for compatability
-# The old thread-based BackgroundSource has been removed and 
+BackgroundSource = ProcessSource  # for compatability
+# The old thread-based BackgroundSource has been removed and
 # replaced by ProcessSource
 
 
 class HashJoiningSource(object):
+
     """A class for equi-joining two data sources."""
 
     def __init__(self, src1, key1, src2, key2):
@@ -215,10 +262,11 @@ class HashJoiningSource(object):
                 yield newrow
 
 
-JoiningSource = HashJoiningSource # for compatability
+JoiningSource = HashJoiningSource  # for compatability
 
 
 class MergeJoiningSource(object):
+
     """A class for merge-joining two sorted data sources"""
 
     def __init__(self, src1, key1, src2, key2):
@@ -243,7 +291,7 @@ class MergeJoiningSource(object):
         rows2 = self.__getnextrows(iter2)
         keyval2 = rows2[0][self.__key2]
 
-        while True: # At one point there will be a StopIteration
+        while True:  # At one point there will be a StopIteration
             if keyval1 == keyval2:
                 # Output rows
                 for part in rows2:
@@ -255,11 +303,11 @@ class MergeJoiningSource(object):
             elif keyval1 < keyval2:
                 row1 = next(iter1)
                 keyval1 = row1[self.__key1]
-            else: # k1 > k2
+            else:  # k1 > k2
                 rows2 = self.__getnextrows(iter2)
                 keyval2 = rows2[0][self.__key2]
 
-    def __getnextrows(self, iter):
+    def __getnextrows(self, iterval):
         res = []
         keyval = None
         if self.__next is not None:
@@ -268,14 +316,14 @@ class MergeJoiningSource(object):
             self.__next = None
         while True:
             try:
-                row = next(iter)
+                row = next(iterval)
             except StopIteration:
                 if res:
                     return res
                 else:
                     raise
             if keyval is None:
-                keyval = row[self.__key2] # for the first row in this round
+                keyval = row[self.__key2]  # for the first row in this round
             if row[self.__key2] == keyval:
                 res.append(row)
             else:
@@ -284,12 +332,13 @@ class MergeJoiningSource(object):
 
 
 class TransformingSource(object):
+
     """A source that applies functions to the rows from another source"""
 
     def __init__(self, source, *transformations):
         """Arguments:
         - source: a data source
-        - *transformations: the transformations to apply. Must be callables 
+        - *transformations: the transformations to apply. Must be callables
           of the form func(row) where row is a dict. Will be applied in the
           given order.
         """
@@ -304,13 +353,14 @@ class TransformingSource(object):
 
 
 class CrossTabbingSource(object):
+
     """A source that produces a crosstab from another source"""
 
     def __init__(self, source, rowvaluesatt, colvaluesatt, values,
                  aggregator=None, nonevalue=0, sortrows=False):
         """Arguments:
         - source: the data source to pull data from
-        - rowvaluesatt: the name of the attribute that holds the values that 
+        - rowvaluesatt: the name of the attribute that holds the values that
           appear as rows in the result
         - colvaluesatt: the name of the attribute that holds the values that
           appear as columns in the result
@@ -333,11 +383,11 @@ class CrossTabbingSource(object):
             self.__aggregator = aggregator
         self.__nonevalue = nonevalue
         self.__sortrows = sortrows
-        self.__allcolumns = set()  
+        self.__allcolumns = set()
         self.__allrows = set()
-        
+
     def __iter__(self):
-        for data in self.__source: # first we iterate over all source data ...
+        for data in self.__source:  # first we iterate over all source data ...
             row = data[self.__rowvaluesatt]
             col = data[self.__colvaluesatt]
             self.__allrows.add(row)
@@ -345,9 +395,9 @@ class CrossTabbingSource(object):
             self.__aggregator.process((row, col), data[self.__values])
 
         # ... and then we build result rows
-        for row in (self.__sortrows and sorted(self.__allrows) \
-                        or self.__allrows): 
-            res = {self.__rowvaluesatt : row}
+        for row in (self.__sortrows and sorted(self.__allrows) or
+                    self.__allrows):
+            res = {self.__rowvaluesatt: row}
             for col in self.__allcolumns:
                 res[col] = \
                     self.__aggregator.finish((row, col), self.__nonevalue)
@@ -355,6 +405,7 @@ class CrossTabbingSource(object):
 
 
 class FilteringSource(object):
+
     """A source that applies a filter to another source"""
 
     def __init__(self, source, filter=bool):
@@ -375,6 +426,7 @@ class FilteringSource(object):
 
 
 class UnionSource(object):
+
     """A source to union other sources (possibly with different types of rows).
     All rows are read from the 1st source before rows are read from the 2nd
     source and so on (to interleave the rows, use a RoundRobinSource)
@@ -393,28 +445,30 @@ class UnionSource(object):
 
 
 class RoundRobinSource(object):
+
     """A source that reads sets of rows from sources in round robin-fashion"""
 
     def __init__(self, sources, batchsize=500):
         """Arguments:
            - sources: a sequence of data sources
            - batchsize: the amount of rows to read from a data source before
-             going to the next data source. Must be positive (to empty a source 
+             going to the next data source. Must be positive (to empty a source
              before going to the next, use UnionSource)
         """
         self.__sources = [iter(src) for src in sources]
-        self.__sources.reverse() # we iterate it from the back in __iter__
+        self.__sources.reverse()  # we iterate it from the back in __iter__
         if not batchsize > 0:
             raise ValueError("batchsize must be positive")
         self.__batchsize = batchsize
 
     def __iter__(self):
         while self.__sources:
-            for i in range(len(self.__sources)-1, -1, -1): #iterate from back
+            # iterate from back
+            for i in range(len(self.__sources) - 1, -1, -1):
                 cursrc = self.__sources[i]
                 # now return up to __batchsize from cursrc
                 try:
-                    for n in range(self.__batchsize):
+                    for _ in range(self.__batchsize):
                         yield next(cursrc)
                 except StopIteration:
                     # we're done with this source and can delete it since
@@ -424,6 +478,7 @@ class RoundRobinSource(object):
 
 
 class DynamicForEachSource(object):
+
     """A source that for each given argument creates a new source that
     will be iterated by this source.
 
@@ -434,14 +489,16 @@ class DynamicForEachSource(object):
     returns a new source to iterate. A DynamicForEachSource instance can be
     given to several ProcessSource instances.
     """
+
     def __init__(self, seq, callee):
         """Arguments:
-           - seq: a sequence with the elements for each of which a unique source 
-             must be created. the elements are given (one by one) to callee.
+           - seq: a sequence with the elements for each of which a unique
+             source must be created. the elements are given (one by one) to
+             callee.
            - callee: a function f(e) that must accept elements as those in the
              seq argument. the function should return a source which then will
              be iterated by this source. the function is called once for every
-             element in seq. 
+             element in seq.
         """
         self.__queue = Queue()  # a multiprocessing.Queue
         if not callable(callee):
